#!/srv/epages/eproot/Perl/bin/perl

use strict;
use Test::More;

use DE_EPAGES::Core::API::File qw ( RunOnGlob );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::PerlTools qw( UsePackage );
use DE_EPAGES::Database::API::Config qw(GetBaseStoreType);

sub Main {

    my $CartridgePackage = 'DE_EPAGES::Database::API::Cartridge';
    UsePackage($CartridgePackage);

    my $Cartridge = $CartridgePackage->new();
    my $BaseStoreTypeConfigDir = "$ENV{EPAGES_CONFIG}/StoreTypes.d/". $Cartridge->version;

    my $TestNumber = 0;
    RunOnGlob($BaseStoreTypeConfigDir, '*.conf', sub {
        # we can't guess the $BaseStoreType of a non-standard storetype
        next unless /^(Site|Store|Monitor|Master|MultiStore)\.conf$/;
        $TestNumber++;
    });
    plan tests => $TestNumber;

    RunOnGlob($BaseStoreTypeConfigDir, '*.conf', sub {
        s,\.conf$,,;
        my ($BaseStoreType) = GetBaseStoreType($_, $BaseStoreTypeConfigDir);
        if (/^(Site|Store|Monitor|Master|MultiStore)$/) {
            my $Result = $_ eq $BaseStoreType;
            # $BaseStoreType might be empty because of dialects
            $Result = 1 unless $BaseStoreType;
            ok($Result, "GetBaseStoreType($_) -> $BaseStoreType");
        } else {
            # we can't guess the $BaseStoreType of a non-standard storetype
            print "GetBaseStoreType($_) -> $BaseStoreType\n";
        }
    });
}

RunScript(Sub=>\&Main);
